.. _api-local-machine:


Package plumbum.machines
========================
.. automodule:: plumbum.machines.env
   :members:
   :special-members:

.. automodule:: plumbum.machines.local
   :members:
   :special-members:

.. automodule:: plumbum.machines.session
   :members:
   :special-members:

.. _api-remote-machines:

Remote Machines
---------------

.. automodule:: plumbum.machines.remote
   :members:
   :special-members:

.. automodule:: plumbum.machines.ssh_machine
   :members:
   :special-members:

.. automodule:: plumbum.machines.paramiko_machine
   :members:
   :special-members:
